

# Enhanced Logger

这是一个基于 [Loguru](https://github.com/Delgan/loguru) 的增强日志工具包，支持：

- 自定义日志格式
- 日志轮转及保留策略
- 上下文信息管理（如 `request_id`）
- 远程日志收集
- 统一异常处理
- 以及更多定制化功能

## 安装

```bash
pip install xdeek_logger



